==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXClusterAdd.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXClusterAdd::nodeAdd{package NXClusterAdd;no warnings;(my $line=shift (@_))
;(my (@options)=());my ($nxserverPid);push (@options,
"\x67\x65\x74\x20\x70\x69\x64",(\$nxserverPid));main::nxrequire (
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65");my (
$socketServer);NXConsole::createConsole ();(my $slaveIN=
NXConsole::getConsoleChildIN ());(my $slaveOUT=NXConsole::getConsoleChildOUT ())
;($socketServer=NXConsole::getConsoleDescriptor ());Logger::debug (((((((
"\x70\x74\x79\x20\x5b".$socketServer).
"\x5d\x20\x73\x6c\x61\x76\x65\x20\x70\x74\x79\x20\x49\x4e\x2f\x4f\x55\x54\x20\x5b"
).$slaveIN)."\x2f").$slaveOUT)."\x5d\x2e"));push (@options,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x69\x6e",$slaveIN);push (@options,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x6f\x75\x74",$slaveOUT);push (@options
,"\x45\x52\x52\x69\x6e\x4f\x55\x54");push (@options,
"\x63\x6c\x6f\x73\x65\x41\x66\x74\x65\x72\x52\x75\x6e",$slaveIN);push (@options,
"\x6c\x65\x61\x76\x65\x20\x73\x74\x64\x69\x6e\x20\x6f\x70\x65\x6e");push (
@options,"\x6c\x65\x61\x76\x65\x20\x73\x74\x64\x6f\x75\x74\x20\x6f\x70\x65\x6e")
;Common::NXCore::cleanOutLanguageCasesInEnvironemt ();push (@options,
"\x66\x75\x6c\x6c\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74");push (
@options,"\x72\x75\x6e\x20\x69\x6e\x20\x62\x67");(my (@command)=());if (($>==
(0x078d+ 3753-0x1636))){Logger::debug (
"\x45\x66\x66\x65\x63\x74\x69\x76\x65\x20\x75\x73\x65\x72\x20\x69\x73\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x2c\x20\x73\x6b\x69\x70\x20\x27\x73\x75\x64\x6f\x27\x2e"
);}else{(my $commandSudo=Common::NXShellCommands::checkPath ("\x73\x75\x64\x6f")
);push (@command,$commandSudo,"\x2d\x53");push (@options,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");}
push (@command,
"\x2f\x65\x74\x63\x2f\x4e\x58\x2f\x6e\x78\x73\x65\x72\x76\x65\x72");push (
@command,"\x2d\x2d\x63\x6c\x75\x73\x74\x65\x72\x6e\x6f\x64\x65\x61\x64\x64");
main::nxRunCommand ((\@command),(\@options));(my $selector=
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x65\x6c\x65\x63\x74\x6f\x72"->new)
;(my $signalFd=$$NXBegin::parser{"\x53\x69\x67\x6e\x61\x6c"});$selector->add (
$signalFd);$selector->add ($socketServer);$selector->add (main::nxgetSTDIN ());my (
$read_buf);my ($bytes_read);(my $pwdalreadysent=(0x1681+ 412-0x181d));(my $buffer
=(""));(my $paramsAlreadySend=(0x074a+ 7169-0x234b));while ((my (@ready)=
$selector->can_read)){Logger::debug (((
"\x63\x61\x6e\x5f\x72\x65\x61\x64\x20\x5b".join ($",@ready))."\x5d"));foreach my $fh
 (@ready){Logger::debug (((
"\x43\x68\x65\x63\x6b\x69\x6e\x67\x20\x46\x48\x20\x5b".$fh)."\x5d"));if (($fh==
$socketServer)){($read_buf=(""));($bytes_read=main::nxread ($fh,(\$read_buf),
(0x1864+ 5614-0x1e52)));Logger::debug (((((
"\x52\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x63\x6c\x75\x73\x74\x65\x72\x4e\x6f\x64\x65\x41\x64\x64\x20\x5b"
.$read_buf)."\x5d\x20\x5b").$bytes_read)."\x5d"));if ((($bytes_read eq 
(0x1454+ 744-0x173c))or (not (defined ($bytes_read))))){Logger::debug (
"\x4e\x6f\x74\x68\x69\x6e\x67\x20\x74\x6f\x20\x72\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x63\x6c\x75\x73\x74\x65\x72\x4e\x6f\x64\x65\x41\x64\x64\x2e"
);(my $message=
"\x53\x75\x64\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x6f\x6e\x20\x63\x6c\x75\x73\x74\x65\x72\x20\x6e\x6f\x64\x65\x20\x65\x6e\x64\x73\x20\x75\x6e\x65\x78\x70\x65\x63\x74\x65\x64\x6c\x79"
);(my $bytes=main::nxwrite (main::nxgetSTDOUT (),($message."\x0a")));
main::nxwrite (main::nxgetSTDOUT (),(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_CLUSTER_NODE_PARAMS)."\x20\x65\x72\x72\x6f\x72\x3d").
main::urlencode ($message))."\x20\x0a"));$selector->remove ($fh);$selector->
remove ($signalFd);return ((0x0424+ 3897-0x135d));}($buffer.=$read_buf);
Logger::debug (((
"\x43\x75\x72\x72\x65\x6e\x74\x20\x62\x75\x66\x66\x65\x72\x20\x5b".$buffer).
"\x5d\x2e"));if (Common::NXShellCommands::isNotInSudoersMessage ($read_buf)){(my $message
=
"\x55\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x69\x6e\x20\x73\x75\x64\x6f\x65\x72\x73\x20\x66\x69\x6c\x65"
);Logger::warning ($message);main::nxwrite (main::nxgetSTDOUT (),((((
"\x4e\x58\x3e\x20".$GLOBAL::MSG_CLUSTER_NODE_PARAMS).
"\x20\x65\x72\x72\x6f\x72\x3d").main::urlencode ($message))."\x20\x0a"));
$selector->remove ($socketServer);$selector->remove ($signalFd);return (
(0x089c+ 7688-0x26a3));}elsif (Common::NXShellCommands::isNotAdministrator (
$read_buf)){(my $message=
"\x55\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72"
);Logger::warning ($message);main::nxwrite (main::nxgetSTDOUT (),((((
"\x4e\x58\x3e\x20".$GLOBAL::MSG_CLUSTER_NODE_PARAMS).
"\x20\x65\x72\x72\x6f\x72\x3d").main::urlencode ($message))."\x20\x0a"));
$selector->remove ($socketServer);$selector->remove ($signalFd);return (
(0x18ad+ 2511-0x227b));}elsif (Common::NXShellCommands::isPasswordRequestMessage
 ($read_buf)){if (($pwdalreadysent==(0x13f4+ 4465-0x2565))){(my $message=((
"\x4e\x58\x3e\x20".$GLOBAL::MSG_ASK_FOR_PASSWORD).
"\x20\x50\x61\x73\x73\x77\x6f\x72\x64\x20\x6e\x65\x65\x64\x65\x64\x2e\x20\x43\x6c\x75\x73\x74\x65\x72\x20\x61\x64\x64\x20\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x20\x0a"
));(my $writtenbytes=main::nxwrite (main::nxgetSTDOUT (),$message));
Logger::debug (((((
"\x41\x73\x6b\x69\x6e\x67\x20\x66\x6f\x72\x20\x73\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x5b"
.$message)."\x5d\x20\x5b").$writtenbytes)."\x5d"));($pwdalreadysent=
(0x05f9+ 796-0x0914));}else{(my $bytes=main::nxwrite ($socketServer,
"\x0a\x0a\x0a"));(my $error=
"\x53\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x6d\x61\x74\x63\x68"
);(my $message=(((("\x4e\x58\x3e\x20".$GLOBAL::MSG_CLUSTER_NODE_PARAMS).
"\x20\x65\x72\x72\x6f\x72\x3d").main::urlencode ($error))."\x20\x0a"));(my $writtenbytes
=main::nxwrite (main::nxgetSTDOUT (),$message));(my $bytes=main::nxwrite (
main::nxgetSTDOUT (),($message."\x0a")));$selector->remove ($socketServer);
$selector->remove ($signalFd);if ($selector->exists (main::nxgetSTDIN ())){
$selector->remove (main::nxgetSTDIN ());}return ((0x25d3+ 229-0x26b7));}}elsif (
($read_buf=~ /NX> $GLOBAL::MSG_CLUSTER_NODE_PARAMS/ )){if (($paramsAlreadySend==
(0x17d6+ 2722-0x2278))){if (($pwdalreadysent==(0x06a7+ 6357-0x1f7c))){
Logger::debug (((((
"\x53\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x64\x6f\x20\x6e\x6f\x74\x20\x6e\x65\x65\x64\x20\x5b"
.$message)."\x5d\x20\x5b").$writtenbytes)."\x5d"));}(my $message=((((
"\x4e\x58\x3e\x20".$GLOBAL::MSG_CLUSTER_NODE_PARAMS).
"\x20\x70\x61\x72\x61\x6d\x73\x3d").$line)."\x20"));my (@bits);push (@bits,
substr ($message,(0x004b+ 1336-0x0583),(0x04c1+ 2399-0x0a38),("")))while length 
($message);foreach my $byte (@bits){($byte.="\x0a");(my $bytes=main::nxwrite (
$socketServer,$byte));Logger::debug ((((("\x53\x65\x6e\x74\x20".$bytes).
"\x20\x62\x79\x74\x65\x73\x20\x27").$byte).
"\x27\x20\x74\x6f\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x63\x6c\x75\x73\x74\x65\x72\x6e\x6f\x64\x65\x61\x64\x64\x2e"
));}($paramsAlreadySend=(0x0d22+ 4866-0x2023));}else{Logger::debug (
"\x50\x72\x65\x76\x65\x6e\x74\x20\x73\x65\x6e\x64\x69\x6e\x67\x20\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x73\x20\x69\x6e\x20\x6c\x6f\x6f\x70\x2e"
);}}if (($buffer=~ /NX> $GLOBAL::MSG_CLUSTER_NODE_PARAMS_RESULT params=(.*) / ))
{Logger::debug (((
"\x4b\x65\x79\x20\x66\x72\x6f\x6d\x20\x63\x6c\x75\x73\x74\x65\x72\x20\x6e\x6f\x64\x65\x20\x72\x65\x73\x75\x6c\x74\x3a\x20\x5b"
.$1)."\x5d"));(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_CLUSTER_NODE_PARAMS)."\x20\x70\x61\x72\x61\x6d\x73\x3d").$1)."\x20"
));(my $bytes=main::nxwrite (main::nxgetSTDOUT (),($message."\x0a")));$selector
->remove ($socketServer);$selector->remove ($signalFd);if ($selector->exists (
main::nxgetSTDIN ())){$selector->remove (main::nxgetSTDIN ());}}elsif (($buffer
=~ /NX> $GLOBAL::MSG_CLUSTER_NODE_PARAMS_RESULT error=(.*) / )){Logger::debug ((
(
"\x45\x72\x72\x6f\x72\x20\x66\x72\x6f\x6d\x20\x63\x6c\x75\x73\x74\x65\x72\x20\x6e\x6f\x64\x65\x3a\x20\x5b"
.$1)."\x5d"));(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_CLUSTER_NODE_PARAMS)."\x20\x65\x72\x72\x6f\x72\x3d").$1)."\x20"));(my $bytes
=main::nxwrite (main::nxgetSTDOUT (),($message."\x0a")));$selector->remove (
$socketServer);$selector->remove ($signalFd);if ($selector->exists (
main::nxgetSTDIN ())){$selector->remove (main::nxgetSTDIN ());}}}elsif (($fh==
main::nxgetSTDIN ())){my ($read_buf);(my $bytes_read=main::nxread ($fh,(
\$read_buf),(0x16ec+ 4861-0x19e9)));Logger::debug (((((
"\x52\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x53\x54\x44\x49\x4e\x20\x5b".$read_buf
)."\x5d\x20\x5b").$bytes_read)."\x5d"));if (($bytes_read==(0x0450+ 8588-0x25dc))
){Logger::debug ("\x52\x65\x6d\x6f\x76\x65\x20\x53\x54\x44\x49\x4e\x2e");
$selector->remove ($fh);}elsif (($read_buf=~ /NX> $GLOBAL::MSG_PASSWORD_ANSWER password=(.*) / )
){(my $password=$1);(my $bytes=main::nxwrite ($socketServer,($password.
"\x0a\x0a\x0a")));Logger::debug (((
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x74\x6f\x20\x73\x75\x64\x6f\x20\x5b"
.$bytes)."\x5d"));$selector->remove (main::nxgetSTDIN ());}}}}}package 
NXClusterAdd;no warnings;return ((0x1821+ 1011-0x1c13));

==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXClusterAdd.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXClusterAdd::nodeAdd{package NXClusterAdd;no warnings;(my $line=shift (@_))
;(my (@options)=());my ($nxserverPid);push (@options,
"\x67\x65\x74\x20\x70\x69\x64",(\$nxserverPid));main::nxrequire (
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65");my (
$socketServer);NXConsole::createConsole ();(my $slaveIN=
NXConsole::getConsoleChildIN ());(my $slaveOUT=NXConsole::getConsoleChildOUT ())
;($socketServer=NXConsole::getConsoleDescriptor ());Logger::debug (((((((
"\x70\x74\x79\x20\x5b".$socketServer).
"\x5d\x20\x73\x6c\x61\x76\x65\x20\x70\x74\x79\x20\x49\x4e\x2f\x4f\x55\x54\x20\x5b"
).$slaveIN)."\x2f").$slaveOUT)."\x5d\x2e"));push (@options,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x69\x6e",$slaveIN);push (@options,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x6f\x75\x74",$slaveOUT);push (@options
,"\x45\x52\x52\x69\x6e\x4f\x55\x54");push (@options,
"\x63\x6c\x6f\x73\x65\x41\x66\x74\x65\x72\x52\x75\x6e",$slaveIN);push (@options,
"\x6c\x65\x61\x76\x65\x20\x73\x74\x64\x69\x6e\x20\x6f\x70\x65\x6e");push (
@options,"\x6c\x65\x61\x76\x65\x20\x73\x74\x64\x6f\x75\x74\x20\x6f\x70\x65\x6e")
;Common::NXCore::cleanOutLanguageCasesInEnvironemt ();push (@options,
"\x66\x75\x6c\x6c\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74");push (
@options,"\x72\x75\x6e\x20\x69\x6e\x20\x62\x67");(my (@command)=());if (($>==
(0x00ba+ 1183-0x0559))){Logger::debug (
"\x45\x66\x66\x65\x63\x74\x69\x76\x65\x20\x75\x73\x65\x72\x20\x69\x73\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x2c\x20\x73\x6b\x69\x70\x20\x27\x73\x75\x64\x6f\x27\x2e"
);}else{(my $commandSudo=Common::NXShellCommands::checkPath ("\x73\x75\x64\x6f")
);push (@command,$commandSudo,"\x2d\x53");push (@options,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");}
push (@command,
"\x2f\x65\x74\x63\x2f\x4e\x58\x2f\x6e\x78\x73\x65\x72\x76\x65\x72");push (
@command,"\x2d\x2d\x63\x6c\x75\x73\x74\x65\x72\x6e\x6f\x64\x65\x61\x64\x64");
main::nxRunCommand ((\@command),(\@options));(my $selector=
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x65\x6c\x65\x63\x74\x6f\x72"->new)
;(my $signalFd=$$NXBegin::parser{"\x53\x69\x67\x6e\x61\x6c"});$selector->add (
$signalFd);$selector->add ($socketServer);$selector->add (main::nxgetSTDIN ());my (
$read_buf);my ($bytes_read);(my $pwdalreadysent=(0x0d6d+ 6420-0x2681));(my $buffer
=(""));(my $paramsAlreadySend=(0x0454+ 4820-0x1728));while ((my (@ready)=
$selector->can_read)){Logger::debug (((
"\x63\x61\x6e\x5f\x72\x65\x61\x64\x20\x5b".join ($",@ready))."\x5d"));foreach my $fh
 (@ready){Logger::debug (((
"\x43\x68\x65\x63\x6b\x69\x6e\x67\x20\x46\x48\x20\x5b".$fh)."\x5d"));if (($fh==
$socketServer)){($read_buf=(""));($bytes_read=main::nxread ($fh,(\$read_buf),
(0x13f9+ 1132-0x0865)));Logger::debug (((((
"\x52\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x63\x6c\x75\x73\x74\x65\x72\x4e\x6f\x64\x65\x41\x64\x64\x20\x5b"
.$read_buf)."\x5d\x20\x5b").$bytes_read)."\x5d"));if ((($bytes_read eq 
(0x0b3f+ 5587-0x2112))or (not (defined ($bytes_read))))){Logger::debug (
"\x4e\x6f\x74\x68\x69\x6e\x67\x20\x74\x6f\x20\x72\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x63\x6c\x75\x73\x74\x65\x72\x4e\x6f\x64\x65\x41\x64\x64\x2e"
);(my $message=
"\x53\x75\x64\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x6f\x6e\x20\x63\x6c\x75\x73\x74\x65\x72\x20\x6e\x6f\x64\x65\x20\x65\x6e\x64\x73\x20\x75\x6e\x65\x78\x70\x65\x63\x74\x65\x64\x6c\x79"
);(my $bytes=main::nxwrite (main::nxgetSTDOUT (),($message."\x0a")));
main::nxwrite (main::nxgetSTDOUT (),(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_CLUSTER_NODE_PARAMS)."\x20\x65\x72\x72\x6f\x72\x3d").
main::urlencode ($message))."\x20\x0a"));$selector->remove ($fh);$selector->
remove ($signalFd);return ((0x1d7c+ 289-0x1e9d));}($buffer.=$read_buf);
Logger::debug (((
"\x43\x75\x72\x72\x65\x6e\x74\x20\x62\x75\x66\x66\x65\x72\x20\x5b".$buffer).
"\x5d\x2e"));if (Common::NXShellCommands::isNotInSudoersMessage ($read_buf)){(my $message
=
"\x55\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x69\x6e\x20\x73\x75\x64\x6f\x65\x72\x73\x20\x66\x69\x6c\x65"
);Logger::warning ($message);main::nxwrite (main::nxgetSTDOUT (),((((
"\x4e\x58\x3e\x20".$GLOBAL::MSG_CLUSTER_NODE_PARAMS).
"\x20\x65\x72\x72\x6f\x72\x3d").main::urlencode ($message))."\x20\x0a"));
$selector->remove ($socketServer);$selector->remove ($signalFd);return (
(0x0355+ 4588-0x1540));}elsif (Common::NXShellCommands::isNotAdministrator (
$read_buf)){(my $message=
"\x55\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72"
);Logger::warning ($message);main::nxwrite (main::nxgetSTDOUT (),((((
"\x4e\x58\x3e\x20".$GLOBAL::MSG_CLUSTER_NODE_PARAMS).
"\x20\x65\x72\x72\x6f\x72\x3d").main::urlencode ($message))."\x20\x0a"));
$selector->remove ($socketServer);$selector->remove ($signalFd);return (
(0x001f+ 6598-0x19e4));}elsif (Common::NXShellCommands::isPasswordRequestMessage
 ($read_buf)){if (($pwdalreadysent==(0x1662+ 1208-0x1b1a))){(my $message=((
"\x4e\x58\x3e\x20".$GLOBAL::MSG_ASK_FOR_PASSWORD).
"\x20\x50\x61\x73\x73\x77\x6f\x72\x64\x20\x6e\x65\x65\x64\x65\x64\x2e\x20\x43\x6c\x75\x73\x74\x65\x72\x20\x61\x64\x64\x20\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x20\x0a"
));(my $writtenbytes=main::nxwrite (main::nxgetSTDOUT (),$message));
Logger::debug (((((
"\x41\x73\x6b\x69\x6e\x67\x20\x66\x6f\x72\x20\x73\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x5b"
.$message)."\x5d\x20\x5b").$writtenbytes)."\x5d"));($pwdalreadysent=
(0x0086+ 2264-0x095d));}else{(my $bytes=main::nxwrite ($socketServer,
"\x0a\x0a\x0a"));(my $error=
"\x53\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x6d\x61\x74\x63\x68"
);(my $message=(((("\x4e\x58\x3e\x20".$GLOBAL::MSG_CLUSTER_NODE_PARAMS).
"\x20\x65\x72\x72\x6f\x72\x3d").main::urlencode ($error))."\x20\x0a"));(my $writtenbytes
=main::nxwrite (main::nxgetSTDOUT (),$message));(my $bytes=main::nxwrite (
main::nxgetSTDOUT (),($message."\x0a")));$selector->remove ($socketServer);
$selector->remove ($signalFd);if ($selector->exists (main::nxgetSTDIN ())){
$selector->remove (main::nxgetSTDIN ());}return ((0x0238+ 5689-0x1870));}}elsif 
(($read_buf=~ /NX> $GLOBAL::MSG_CLUSTER_NODE_PARAMS/ )){if (($paramsAlreadySend
==(0x1b3c+ 2711-0x25d3))){if (($pwdalreadysent==(0x0e12+ 4933-0x2157))){
Logger::debug (((((
"\x53\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x64\x6f\x20\x6e\x6f\x74\x20\x6e\x65\x65\x64\x20\x5b"
.$message)."\x5d\x20\x5b").$writtenbytes)."\x5d"));}(my $message=((((
"\x4e\x58\x3e\x20".$GLOBAL::MSG_CLUSTER_NODE_PARAMS).
"\x20\x70\x61\x72\x61\x6d\x73\x3d").$line)."\x20"));my (@bits);push (@bits,
substr ($message,(0x0385+ 7904-0x2265),(0x06a1+ 1311-0x07d8),("")))while length 
($message);foreach my $byte (@bits){($byte.="\x0a");(my $bytes=main::nxwrite (
$socketServer,$byte));Logger::debug ((((("\x53\x65\x6e\x74\x20".$bytes).
"\x20\x62\x79\x74\x65\x73\x20\x27").$byte).
"\x27\x20\x74\x6f\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x63\x6c\x75\x73\x74\x65\x72\x6e\x6f\x64\x65\x61\x64\x64\x2e"
));}($paramsAlreadySend=(0x11af+ 2194-0x1a40));}else{Logger::debug (
"\x50\x72\x65\x76\x65\x6e\x74\x20\x73\x65\x6e\x64\x69\x6e\x67\x20\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x73\x20\x69\x6e\x20\x6c\x6f\x6f\x70\x2e"
);}}if (($buffer=~ /NX> $GLOBAL::MSG_CLUSTER_NODE_PARAMS_RESULT params=(.*) / ))
{Logger::debug (((
"\x4b\x65\x79\x20\x66\x72\x6f\x6d\x20\x63\x6c\x75\x73\x74\x65\x72\x20\x6e\x6f\x64\x65\x20\x72\x65\x73\x75\x6c\x74\x3a\x20\x5b"
.$1)."\x5d"));(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_CLUSTER_NODE_PARAMS)."\x20\x70\x61\x72\x61\x6d\x73\x3d").$1)."\x20"
));(my $bytes=main::nxwrite (main::nxgetSTDOUT (),($message."\x0a")));$selector
->remove ($socketServer);$selector->remove ($signalFd);if ($selector->exists (
main::nxgetSTDIN ())){$selector->remove (main::nxgetSTDIN ());}}elsif (($buffer
=~ /NX> $GLOBAL::MSG_CLUSTER_NODE_PARAMS_RESULT error=(.*) / )){Logger::debug ((
(
"\x45\x72\x72\x6f\x72\x20\x66\x72\x6f\x6d\x20\x63\x6c\x75\x73\x74\x65\x72\x20\x6e\x6f\x64\x65\x3a\x20\x5b"
.$1)."\x5d"));(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_CLUSTER_NODE_PARAMS)."\x20\x65\x72\x72\x6f\x72\x3d").$1)."\x20"));(my $bytes
=main::nxwrite (main::nxgetSTDOUT (),($message."\x0a")));$selector->remove (
$socketServer);$selector->remove ($signalFd);if ($selector->exists (
main::nxgetSTDIN ())){$selector->remove (main::nxgetSTDIN ());}}}elsif (($fh==
main::nxgetSTDIN ())){my ($read_buf);(my $bytes_read=main::nxread ($fh,(
\$read_buf),(0x104a+ 8583-0x21d1)));Logger::debug (((((
"\x52\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x53\x54\x44\x49\x4e\x20\x5b".$read_buf
)."\x5d\x20\x5b").$bytes_read)."\x5d"));if (($bytes_read==(0x2291+ 620-0x24fd)))
{Logger::debug ("\x52\x65\x6d\x6f\x76\x65\x20\x53\x54\x44\x49\x4e\x2e");
$selector->remove ($fh);}elsif (($read_buf=~ /NX> $GLOBAL::MSG_PASSWORD_ANSWER password=(.*) / )
){(my $password=$1);(my $bytes=main::nxwrite ($socketServer,($password.
"\x0a\x0a\x0a")));Logger::debug (((
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x74\x6f\x20\x73\x75\x64\x6f\x20\x5b"
.$bytes)."\x5d"));$selector->remove (main::nxgetSTDIN ());}}}}}package 
NXClusterAdd;no warnings;return ((0x068f+ 7536-0x23fe));
